@@ -3,7 +3,7 @@ package Build::Hopen::G::Goal;
 use Build::Hopen;
 use Build::Hopen::Base;
 
-our $VERSION = '0.000005'; # TRIAL
+our $VERSION = '0.000006'; # TRIAL
 
 use parent 'Build::Hopen::G::Op';
 use Class::Tiny qw(_passthrough);
@@ -17,7 +17,9 @@ Build::Hopen::G::Goal - a named goal in a hopen build
 =head1 SYNOPSIS
 
 A C<Goal> is a named build target, e.g., C<doc> or C<dist>.  The name C<all>
-is reserved for the root goal.
+is reserved for the root goal.  Goals usually appear at the end of the build
+graph, but this is not required --- Goal nodes can appear anywhere in the
+graph.
 
 =head1 FUNCTIONS
 
@@ -30,21 +32,8 @@ Wraps a L<Build::Hopen::G::PassthroughOp>'s run function.
 # }}}1
 
 sub run {
-    my $self = shift or croak 'Need an instance';
-    return $self->_passthrough->run(@_);
-}
-
-# TODO?  Override the setter so that name 'all' throws?
-
-=head2 describe
-
-Wraps a L<Build::Hopen::G::PassthroughOp>'s describe function.
-
-=cut
-
-sub describe {
-    my $self = shift or croak 'Need an instance';
-    return $self->_passthrough->describe(@_);
+    my $self = shift or croak 'Need an instance';   # Don't need Build::Hopen::Arrrgs
+    return $self->_passthrough->run(@_);            # since this is straight forwarding
 }
 
 =head2 BUILD
@@ -53,6 +42,7 @@ sub describe {
 
 sub BUILD {
     my ($self, $args) = @_;
+    croak 'Goals must have names' unless $args->{name};
     # TODO refactor out the common code between Goal and PassthroughOp
     # rather than wrapping.
     my $p = hnew(PassthroughOp => ($args->{name} . '_inner'));
