@@ -1,15 +1,18 @@
 # Build::Hopen::G::Link - base class for hopen edges
 package Build::Hopen::G::Link;
-use Build::Hopen qw(:default clone);
+use Build::Hopen qw(:default UNSPECIFIED);
 use Build::Hopen::Base;
 
-our $VERSION = '0.000005'; # TRIAL
+our $VERSION = '0.000006'; # TRIAL
 
 use parent 'Build::Hopen::G::Runnable';
 use Class::Tiny {
     greedy => 0
 };
 
+use Build::Hopen::Util::Data qw(clone);
+use Build::Hopen::Arrrgs;
+
 =head1 NAME
 
 Build::Hopen::G::Link - The base class for all hopen links between ops.
@@ -33,12 +36,9 @@ The output is C<{}> if no inputs are provided.
 =cut
 
 sub run {
-    my $self = shift or croak 'Need an instance';
-    my $scope = shift or croak 'Need a scope';
+    my ($self, %args) = parameters('self', [qw(scope; phase generator)], @_);
     hlog { Running => __PACKAGE__ , $self->name };
-    my $hrRetval = {};
-    $hrRetval->{$_} = clone $scope->find($_) foreach $scope->names;
-    return $hrRetval;
+    return $self->passthrough(-scope => $args{scope});
 } #run()
 
 
@@ -51,8 +51,8 @@ Constructor.  Interprets L</greedy>.
 sub BUILD {
     my ($self, $args) = @_;
     $self->want(UNSPECIFIED) if $args->{greedy};
-    use Data::Dumper;
-    #hlog { 'Link::BUILD', Dumper($self) };
+    #hlog { 'Link::BUILD', Dumper($self), Dumper($args) };
+    #hlog { 'Link::BUILD', Dumper($self->scope) };
 } #BUILD()
 
 1;
