@@ -1,12 +1,15 @@
 # Build::Hopen::G::PassthroughOp - A no-op operation
 package Build::Hopen::G::PassthroughOp;
-use Build::Hopen qw(:default clone);
+use Build::Hopen qw(:default UNSPECIFIED);
 use Build::Hopen::Base;
 
-our $VERSION = '0.000005'; # TRIAL
+our $VERSION = '0.000006'; # TRIAL
 
 use parent 'Build::Hopen::G::Op';
 #use Class::Tiny;
+
+use Build::Hopen::Util::Data qw(clone);
+use Build::Hopen::Arrrgs;
 use Storable ();
 
 # Docs {{{1
@@ -31,36 +34,18 @@ L<Build::Hopen::G::DAG> to represent goals.
 
 Do nothing!  Usage:
 
-    my $hrOutputs = $op->run($scope)
+    my $hrOutputs = $op->run(-scope=>$scope)
 
 The output is C<{}> if no inputs are provided.
 
 =cut
 
 sub run {
-    my $self = shift or croak 'Need an instance';
-    my $scope = shift or croak 'Need a scope';
+    my ($self, %args) = parameters('self', [qw(scope; phase generator)], @_);
     hlog { Running => __PACKAGE__ , $self->name };
-    my $hrRetval = {};
-    $hrRetval->{$_} = clone $scope->find($_) foreach $scope->names;
-    return $hrRetval;
+    return $self->passthrough(-scope => $args{scope});
 } #run()
 
-=head2 describe
-
-Return a hashref of C<< {in => (the inputs), out => (the outputs) >>.  The
-implementation here returns C<true> for the inputs, signifying that this op
-will accept anything.  It returns C<true> for the outputs, signifying that this
-op may output anything.
-
-=cut
-
-sub describe {
-    my $self = shift or croak 'Need an instance';
-    return { in => UNSPECIFIED, out => NOTHING };
-        # By default, any inputs; any outputs.
-} #describe()
-
 =head2 BUILD
 
 Constructor
